from wikiresults import wikiparse

class TestResultParse():

#    @classmethod
#    def setup_class(cls):
#        test_datafile = open('f19f_tc3_wikiresults f19f_tc3_wikiresults.txt','r')
#        cls.test_data = test_datafile.read()
#        test_datafile.close()

    def test_parse_single_named_pass_report(self):
        test_data = "{{result|pass|testinggoat}}"

        test_parser = wikiparse.get_parser()

        result = test_parser(test_data).report()

        assert result == {'bug':'', 'result':'pass', 'user':'testinggoat'}


    def test_parse_single_noname_report(self):
        test_data = "{{result|none}}"

        test_parser = wikiparse.get_parser()

        result = test_parser(test_data).report()

        assert result == {'bug':'', 'result':'none', 'user':''}

    def test_parse_single_name_fail_bug_report(self):
        test_data = "{{result|fail|testinggoat|123456}}"

        test_parser = wikiparse.get_parser()

        result = test_parser(test_data).report()

        assert result == {'bug':'123456', 'result':'fail', 'user':'testinggoat'}

    def test_parse_single_greyedout_report(self):
        test_data = '| style="background:lightgrey;"|'

        test_parser = wikiparse.get_parser()

        result = test_parser(test_data).reportrow()

        assert result == [{'bug':'', 'result':'NA', 'user':''}]


    def test_parse_multiple_results(self):
        test_data = """
{{result|fail|testinggoat}}
{{result|pass|djangopony}}
{{result|none}}
{{result|fail|testinggoat|123456}}
"""
        test_parser = wikiparse.get_parser()

        results = test_parser(test_data.strip()).reports()

        assert len(results) == 4

    def test_parse_single_result_with_single_unnamed_ref(self):
        test_data = "{{result|fail|testinggoat|123456}}<ref>\"Set root password\" is spoke #5</ref>"

        test_parser = wikiparse.get_parser()

        result = test_parser(test_data).report()

        assert result == {'bug':'123456', 'result':'fail', 'user':'testinggoat'}

    def test_parse_single_result_with_single_named_ref(self):
        test_data = "{{result|fail|testinggoat|123456}}<ref name=explosion>\"Set root password\" is spoke #5</ref>"

        test_parser = wikiparse.get_parser()

        result = test_parser(test_data).report()

        assert result == {'bug':'123456', 'result':'fail', 'user':'testinggoat'}

    def test_parse_single_unnamed_ref(self):
        test_data = "<ref>\"Set root password\" is spoke #5</ref>"

        test_parser = wikiparse.get_parser()

        result = test_parser(test_data).ref()

        assert result == {'name':'', 'text':'\"Set root password\" is spoke #5'}

    def test_parse_single_named_ref(self):
        test_data = "<ref name=text>\"Set root password\" is spoke #5</ref>"

        test_parser = wikiparse.get_parser()

        result = test_parser(test_data).ref()

        assert result == {'name':'text', 'text':'\"Set root password\" is spoke #5'}

    def test_parse_single_named_ref_content_elsewhere(self):
        test_data = "<ref name=text>"

        test_parser = wikiparse.get_parser()

        result = test_parser(test_data).ref()

        assert result == {'name':'text', 'text':''}

